@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """Classes to represents descriptors of a DwC-A.
 
 - :class:`ArchiveDescriptor` represents the full archive descriptor, initialized from the \
@@ -14,7 +12,6 @@ import csv
 import io
 import os
 import re
-import sys
 import xml.etree.ElementTree as ET
 from typing import Optional, List, Dict, Set
 from xml.etree.ElementTree import Element
@@ -32,20 +29,19 @@ class DataFileDescriptor(object):
     """
 
     def __init__(self,
-                 created_from_file,     # type: bool
-                 raw_element,           # type: Element
-                 represents_corefile,   # type: bool
-                 datafile_type,         # type: Optional[str]
-                 file_location,         # type: str
-                 file_encoding,         # type: str
-                 id_index,              # type: int
-                 coreid_index,          # type: int
-                 fields,                # type: List[Dict]
-                 lines_terminated_by,   # type: str
-                 fields_enclosed_by,    # type: str
-                 fields_terminated_by   # type: str
-                 ):
-        # type: (...) -> None
+                 created_from_file: bool,
+                 raw_element: Element,
+                 represents_corefile: bool,
+                 datafile_type: Optional[str],
+                 file_location: str,
+                 file_encoding: str,
+                 id_index: int,
+                 coreid_index: int,
+                 fields: List[Dict],
+                 lines_terminated_by: str,
+                 fields_enclosed_by: str,
+                 fields_terminated_by: str
+                 ) -> None:
 
         #: True if this descriptor was created by analyzing the data file.
         self.created_from_file = created_from_file
@@ -126,9 +122,6 @@ class DataFileDescriptor(object):
 
             datafile.seek(0)
 
-            dialect.delimiter = str(dialect.delimiter)  # Python 2 fix
-            dialect.quotechar = str(dialect.quotechar)  # Python 2 fix
-
             dr = csv.reader(datafile, dialect)
             columns = next(dr)
 
@@ -203,14 +196,12 @@ class DataFileDescriptor(object):
                    fields_terminated_by=fields_terminated_by)
 
     @property
-    def terms(self):
-        # type: () -> Set[str]
+    def terms(self) -> Set[str]:
         """Return a Python set containing all the Darwin Core terms appearing in file."""
         return set([f['term'] for f in self.fields])
 
     @property
-    def headers(self):
-        # type: () -> List[str]
+    def headers(self) -> List[str]:
         """A list of (ordered) column names that can be used to create a header line for the data file.
 
         Example::
@@ -235,8 +226,7 @@ class DataFileDescriptor(object):
         return [columns[f] for f in sorted(columns.keys())]
 
     @property
-    def short_headers(self):
-        # type: () -> List[str]
+    def short_headers(self) -> List[str]:
         """A list of (ordered) column names (short version) that can be used to create a header line for the data file.
 
            Example::
@@ -248,8 +238,7 @@ class DataFileDescriptor(object):
         return [shorten_term(long_term) for long_term in self.headers]
 
     @property
-    def lines_to_ignore(self):
-        # type: () -> int
+    def lines_to_ignore(self) -> int:
         """Return the number of header lines/lines to ignore in the data file."""
         if self.created_from_file:
             # Single-file archives always have a header line with DwC terms
@@ -261,8 +250,7 @@ class DataFileDescriptor(object):
 class ArchiveDescriptor(object):
     """Class used to encapsulate the whole Metafile (`meta.xml`)."""
 
-    def __init__(self, metaxml_content, files_to_ignore=None):
-        # type: (str, List[str]) -> None
+    def __init__(self, metaxml_content: str, files_to_ignore: List[str] = None) -> None:
         if files_to_ignore is None:
             files_to_ignore = []
 
@@ -310,9 +298,6 @@ def _decode_xml_attribute(raw_element, attribute_name, default_value, encoding):
 
     raw_attribute = raw_element.get(attribute_name)
     if raw_attribute:
-        if sys.version_info[0] == 2:  # Python 2
-            return raw_attribute.decode("string_escape")
-
         return bytes(raw_attribute, encoding).decode("unicode-escape")
 
     return default_value
