@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """High-level classes to open and read DarwinCore Archive."""
 
 import os
@@ -17,7 +15,7 @@ import dwca.vendor
 from dwca.descriptors import ArchiveDescriptor, DataFileDescriptor, shorten_term
 from dwca.exceptions import RowNotFound, InvalidArchive, InvalidSimpleArchive, NotADataFile
 from dwca.files import CSVDataFile
-from dwca.rows import CoreRow, ExtensionRow
+from dwca.rows import CoreRow
 
 
 class DwCAReader(object):
@@ -80,8 +78,7 @@ class DwCAReader(object):
     def __exit__(self, exc_type, exc_value, exc_traceback):
         self.close()
 
-    def __init__(self, path, extensions_to_ignore=None, tmp_dir=None):
-        # type: (str, List[str], str) -> None
+    def __init__(self, path: str, extensions_to_ignore: List[str] = None, tmp_dir: str = None) -> None:
         """Open the Darwin Core Archive."""
         if extensions_to_ignore is None:
             extensions_to_ignore = []
@@ -143,8 +140,7 @@ class DwCAReader(object):
                 msg = "No Metafile was found, but the archive contains multiple files/directories."
                 raise InvalidSimpleArchive(msg)
 
-    def _get_source_metadata(self):
-        # type: () -> Dict[str, Element]
+    def _get_source_metadata(self) -> Dict[str, Element]:
         source_metadata = {}  # type: Dict[str, Element]
         source_metadata_dir = os.path.join(self._working_directory_path, self.source_metadata_directory)
 
@@ -158,8 +154,7 @@ class DwCAReader(object):
         return source_metadata
 
     @property
-    def core_file_location(self):
-        # type: () -> str
+    def core_file_location(self) -> str:
         """The (relative) path to the core data file.
 
         Example: `'occurrence.txt'`
@@ -213,8 +208,7 @@ class DwCAReader(object):
 
         return df
 
-    def orphaned_extension_rows(self):
-        # type: () -> Dict[str, Dict[str, List[int]]]
+    def orphaned_extension_rows(self) -> Dict[str, Dict[str, List[int]]]:
         """Return a dict of the orphaned extension rows.
 
         Orphaned extension rows are extension rows who reference non-existing core rows. This methods returns a dict
@@ -239,7 +233,7 @@ class DwCAReader(object):
             ids = temp_ids.keys()
 
             for extension in self.extension_files:
-                coreid_index = extension.coreid_index.copy()
+                coreid_index = dict((k, v.tolist()) for k, v in extension.coreid_index.items())
                 for id in ids:
                     coreid_index.pop(id, None)
                 indexes[extension.file_descriptor.file_location] = coreid_index
@@ -247,15 +241,13 @@ class DwCAReader(object):
         return indexes
 
     @property
-    def use_extensions(self):
-        # type: () -> bool
+    def use_extensions(self) -> bool:
         """`True` if the archive makes use of extensions."""
         return (self.descriptor is not None) and (len(self.descriptor.extensions) > 0)
 
     @property
     # TODO: decide, test and document what we guarantee about ordering
-    def rows(self):
-        # type: () -> List[CoreRow]
+    def rows(self) -> List[CoreRow]:
         """A list of :class:`rows.CoreRow` objects representing the content of the archive.
 
         .. warning::
@@ -264,8 +256,7 @@ class DwCAReader(object):
         """
         return list(self)
 
-    def get_corerow_by_id(self, row_id):
-        # type: (str) -> CoreRow
+    def get_corerow_by_id(self, row_id: str) -> CoreRow:
         """Return the (core) row whose ID is `row_id`.
 
         :param row_id: ID of the core row you want
@@ -289,20 +280,7 @@ class DwCAReader(object):
 
         raise RowNotFound
 
-    def get_row_by_id(self, row_id):
-        # type: (str) -> CoreRow
-        """
-        .. warning::
-
-            Deprecated: this method has been renamed to :meth:`get_corerow_by_id`.
-
-        """
-        import warnings
-        warnings.warn("This method has been renamed to get_corerow_by_id().", DeprecationWarning)
-        return self.get_corerow_by_id(row_id)
-
-    def get_corerow_by_position(self, position):
-        # type: (int) -> CoreRow
+    def get_corerow_by_position(self, position: int) -> CoreRow:
         """Return a core row according to its position/index in core file.
 
         :param position: the position (starting at 0) of the row you want in the core file.
@@ -323,20 +301,7 @@ class DwCAReader(object):
 
         raise RowNotFound
 
-    def get_row_by_index(self, index):
-        # type: (int) -> CoreRow
-        """
-        .. warning::
-
-            Deprecated: this method has been renamed to :meth:`get_corerow_by_position`.
-
-        """
-        import warnings
-        warnings.warn("This method has been renamed to get_corerow_by_position().", DeprecationWarning)
-        return self.get_corerow_by_position(index)
-
-    def absolute_temporary_path(self, relative_path):
-        # type: (str) -> str
+    def absolute_temporary_path(self, relative_path: str) -> str:
         """Return the absolute path of a file located within the archive.
 
         This method allows raw access to the files contained in the archive. It can be useful to open additional, \
@@ -361,8 +326,7 @@ class DwCAReader(object):
         """
         return os.path.abspath(os.path.join(self._working_directory_path, relative_path))
 
-    def get_descriptor_for(self, relative_path):
-        # type: (str) -> DataFileDescriptor
+    def get_descriptor_for(self, relative_path: str) -> DataFileDescriptor:
         """Return a descriptor for the data file located at relative_path.
 
         :param relative_path: the path (relative to the archive root) to the data file you want info about.
@@ -384,8 +348,7 @@ class DwCAReader(object):
 
         raise NotADataFile("{fn} is not a data file".format(fn=relative_path))
 
-    def _is_valid_simple_archive(self):
-        # type: () -> str
+    def _is_valid_simple_archive(self) -> str:
 
         # If the working dir appear to contains a valid simple darwin core archive
         # (one single data file + possibly some metadata), returns the name of the data file.
@@ -402,8 +365,7 @@ class DwCAReader(object):
 
         raise InvalidSimpleArchive()
 
-    def open_included_file(self, relative_path, *args, **kwargs):
-        # type: (str, Any, Any) -> IO
+    def open_included_file(self, relative_path: str, *args: Any, **kwargs: Any) -> IO:
         """Simple wrapper around Python's build-in `open` function.
 
         To be used only for reading.
@@ -414,8 +376,7 @@ class DwCAReader(object):
         """
         return open(self.absolute_temporary_path(relative_path), *args, **kwargs)
 
-    def _parse_metadata_file(self):
-        # type: () -> Optional[Element]
+    def _parse_metadata_file(self) -> Optional[Element]:
         """Load the archive (scientific) Metadata file, parse it with\
         ElementTree and return its content (or `None` if the archive has no metadata).
 
@@ -442,13 +403,11 @@ class DwCAReader(object):
 
         assert False  # For MyPy, see: https://github.com/python/mypy/issues/4223#issuecomment-342865133
 
-    def _parse_xml_included_file(self, relative_path):
-        # type: (str) -> Element
+    def _parse_xml_included_file(self, relative_path: str) -> Element:
         """Load, parse and returns (as ElementTree.Element) XML file located at relative_path."""
         return ET.parse(self.absolute_temporary_path(relative_path)).getroot()
 
-    def _unzip_or_untar(self):
-        # type: () -> str
+    def _unzip_or_untar(self) -> str:
         """Create a temporary dir. and uncompress/unarchive self.archive_path there.
 
         Returns the path to that temporary directory.
@@ -471,8 +430,7 @@ class DwCAReader(object):
 
         return tmp_dir
 
-    def _extract(self):
-        # type: () -> Tuple[str, str]
+    def _extract(self) -> Tuple[str, str]:
         """Extract the current (Zip of Tar) archive in a temporary directory and return paths.
 
         Returns (path_to_clean_afterwards, path_to_content)
@@ -490,8 +448,7 @@ class DwCAReader(object):
 
         return extracted_dir, content_dir
 
-    def close(self):
-        # type: () -> None
+    def close(self) -> None:
         """Close the Darwin Core Archive and remove temporary/working files.
 
         .. note::
@@ -507,21 +464,18 @@ class DwCAReader(object):
         if self._directory_to_clean:
             rmtree(self._directory_to_clean, False)
 
-    def core_contains_term(self, term_url):
-        # type: (str) -> bool
+    def core_contains_term(self, term_url: str) -> bool:
         """Return `True` if the Core file of the archive contains the `term_url` term."""
         return term_url in self.core_file.file_descriptor.terms
 
-    def __iter__(self):
-        # type: () -> DwCAReader
+    def __iter__(self) -> 'DwCAReader':
         self._corefile_pointer = 0
         return self
 
     def __next__(self):
         return self.next()
 
-    def next(self):  # NOQA
-        # type: () -> CoreRow
+    def next(self) -> CoreRow:  # NOQA
         try:
             row = self.core_file.get_row_by_position(self._corefile_pointer)
 
@@ -533,23 +487,3 @@ class DwCAReader(object):
             return row
         except IndexError:
             raise StopIteration
-
-
-class GBIFResultsReader(DwCAReader):
-    """This class is used to represent the slightly augmented variant of Darwin Core Archive produced by the GBIF Data
-    Portal when exporting occurrences.
-
-    .. warning:: This class is deprecated. See :doc:`gbif_results` to learn how to achieve the same results with \
-    :class:`.DwCAReader`.
-
-    """
-
-    @property
-    def citations(self):
-        """The content of the `citations.txt` file included in the archive."""
-        return self.open_included_file('citations.txt').read()
-
-    @property
-    def rights(self):
-        """The content of the `rights.txt` file included in the archive."""
-        return self.open_included_file('rights.txt').read()
